@@ -45,7 +45,8 @@
 #include <QMenu>
 #include <QMouseEvent>
 #include <QPointer>
-#include <QRegExp>
+#include <QRegularExpression>
+#include <QTextBlock>
 
 DEBUG_REGISTER(CodeEditor)
 
@@ -53,7 +54,7 @@ DEBUG_REGISTER(CodeEditor)
  * Constructor.
  */
 CodeEditor::CodeEditor(const QString & text, CodeViewerDialog * parent, CodeDocument * doc)
-  : KTextEdit(text, parent)
+  : QTextEdit(text, parent)
 {
     init(parent, doc);
 }
@@ -62,7 +63,7 @@ CodeEditor::CodeEditor(const QString & text, CodeViewerDialog * parent, CodeDocu
  * Constructor.
  */
 CodeEditor::CodeEditor(CodeViewerDialog * parent, CodeDocument * doc)
-  : KTextEdit(parent)
+  : QTextEdit(parent)
 {
     init(parent, doc);
 }
@@ -79,7 +80,7 @@ CodeEditor::~CodeEditor()
  */
 void CodeEditor::clearText()
 {
-    m_selectedTextBlock = 0;
+    m_selectedTextBlock = nullptr;
 
     // now call super-class
     clear();
@@ -142,9 +143,9 @@ bool CodeEditor::close()
     // capture last code block, if it exists
     if (m_lastTextBlockToBeEdited) {
         updateTextBlockFromText (m_lastTextBlockToBeEdited);
-        m_lastTextBlockToBeEdited = 0;
+        m_lastTextBlockToBeEdited = nullptr;
     }
-    return KTextEdit::close();
+    return QTextEdit::close();
 }
 
 /**
@@ -201,7 +202,7 @@ void CodeEditor::keyPressEvent(QKeyEvent * e)
     if ((e->key() == 10) || (e->key() == 13) || (e->text() == QString::fromLatin1("\r\n"))) {
         m_newLinePressed = true;
     }
-    KTextEdit::keyPressEvent(e);
+    QTextEdit::keyPressEvent(e);
 }
 
 /**
@@ -223,7 +224,7 @@ void CodeEditor::loadFromDocument()
     if (isNonBlank(header)) {
         logDebug1("CodeEditor::loadFromDocument header for document: %1", header);
         insertText(header, m_parentDoc->getHeader(), false, state().fontColor,
-               state().nonEditBlockColor, 0, componentName);
+               state().nonEditBlockColor, nullptr, componentName);
     }
 
     // now all the text blocks in the document
@@ -267,7 +268,7 @@ void CodeEditor::insertText(const QString & text, TextBlock * parent,
                 }
             }
         }
-        KTextEdit::append(text); // put actual text in. Use insert instead of append so history is preserved?
+        QTextEdit::append(text); // put actual text in. Use insert instead of append so history is preserved?
     }
     else {
         isInsert = true;
@@ -332,7 +333,7 @@ void CodeEditor::insertText(const QString & text, TextBlock * parent,
             TextBlockInfo * thisTbInfo = it.value();
             int firstLoc = m_textBlockList.indexOf(tblock);
 
-            foreach (ParaInfo * pi, thisTbInfo->m_paraList) {
+            for(ParaInfo * pi : thisTbInfo->m_paraList) {
                 int minPara = pi->start + firstLoc;
 
                 // only worth doing if in range of the whole representation
@@ -361,17 +362,17 @@ void CodeEditor::insertText(const QString & text, TextBlock * parent,
 void CodeEditor::appendText(TextBlockList * items)
 {
     logDebug0("CodeEditor::appendText text block list");
-    foreach (TextBlock* tb, *items) {
+    for(TextBlock* tb : *items) {
         // types of things we may cast our text block into
         // This isnt efficient, and is a vote for recording
         // code block types in an enumerated list somewhere,
         // as well as a generic attribute "blockType" we could
         // quickly access, rather than casting. -b.t.
-        HierarchicalCodeBlock * hb = 0;
-        CodeMethodBlock * mb = 0;
-        CodeClassFieldDeclarationBlock * db = 0;
-        CodeBlockWithComments * cb = 0;
-        // CodeComment * cm = 0;
+        HierarchicalCodeBlock *hb = nullptr;
+        CodeMethodBlock *mb = nullptr;
+        CodeClassFieldDeclarationBlock *db = nullptr;
+        CodeBlockWithComments *cb = nullptr;
+        // CodeComment *cm = nullptr;
         if ((hb = dynamic_cast<HierarchicalCodeBlock *>(tb)))
             appendText(hb);
         else if ((mb = dynamic_cast<CodeMethodBlock*>(tb)))
@@ -430,13 +431,13 @@ void CodeEditor::appendText(CodeBlockWithComments * cb)
     QColor bgcolor = state().editBlockColor;
     QString componentName = QString::fromLatin1("CodeBlock");
 
-    appendText(cb->getComment(), cb, 0, componentName);
+    appendText(cb->getComment(), cb, nullptr, componentName);
 
     if (!cb->getWriteOutText() && m_showHiddenBlocks)
         bgcolor = state().hiddenColor;
 
     if (isNonBlank(body))
-        insertText(body, cb, true, state().fontColor, bgcolor, 0);
+        insertText(body, cb, true, state().fontColor, bgcolor, nullptr);
 }
 
 /**
@@ -511,7 +512,7 @@ void CodeEditor::appendText(CodeMethodBlock * mb)
     // ugly, but we need to know if there is a parent object here.
     CodeOperation * op = dynamic_cast<CodeOperation*>(mb);
     CodeAccessorMethod * accessor = dynamic_cast<CodeAccessorMethod*>(mb);
-    UMLObject * parentObj = 0;
+    UMLObject  *parentObj = nullptr;
     if (op) {
         parentObj = op->getParentOperation();
         if (((UMLOperation*)parentObj)->isConstructorOperation())
@@ -571,7 +572,7 @@ void CodeEditor::appendText(HierarchicalCodeBlock * hblock)
         return;
 
     OwnedHierarchicalCodeBlock * test = dynamic_cast<OwnedHierarchicalCodeBlock *>(hblock);
-    UMLObject * parentObj = 0;
+    UMLObject  *parentObj = nullptr;
     QString componentName;
     QColor paperColor = state().nonEditBlockColor;
     if (test) {
@@ -669,7 +670,7 @@ void CodeEditor::slotChangeSelectedBlockView()
 void CodeEditor::slotChangeSelectedBlockCommentView()
 {
     TextBlock * tb = m_selectedTextBlock;
-    CodeBlockWithComments * cb = 0;
+    CodeBlockWithComments  *cb = nullptr;
     if (tb && (cb = dynamic_cast<CodeBlockWithComments*>(tb))) {
         CodeComment* codcom = cb->getComment();
         if (codcom) {
@@ -696,7 +697,7 @@ void CodeEditor::slotInsertCodeBlockBeforeSelected()
     QString body = newBlock->formatMultiLineText(newBlock->getText(), newBlock->getIndentationString(), QString::fromLatin1("\n"));
 
     insertText(body, newBlock, true, state().fontColor,
-           state().editBlockColor, 0, QString::fromLatin1("CodeBlock"), location);
+           state().editBlockColor, nullptr, QString::fromLatin1("CodeBlock"), location);
 }
 
 /**
@@ -719,7 +720,7 @@ void CodeEditor::slotInsertCodeBlockAfterSelected()
     QString body = newBlock->formatMultiLineText(newBlock->getText(), newBlock->getIndentationString(), QString::fromLatin1("\n"));
 
     insertText(body, newBlock, true, state().fontColor,
-           state().editBlockColor, 0, QString::fromLatin1("CodeBlock"), location);
+           state().editBlockColor, nullptr, QString::fromLatin1("CodeBlock"), location);
 }
 
 /**
@@ -841,7 +842,7 @@ void CodeEditor::slotCopyTextBlock()
         m_textBlockToPaste = CodeGenFactory::newCodeComment(m_parentDoc);
     else {
         logError0("CodeEditor cannot copy selected block of unknown type");
-        m_textBlockToPaste = 0;
+        m_textBlockToPaste = nullptr;
         return; // error!
     }
     m_textBlockToPaste->setAttributesFromObject(m_selectedTextBlock);
@@ -862,13 +863,13 @@ void CodeEditor::slotCutTextBlock()
         // we don't want to lose them
         if (m_lastTextBlockToBeEdited && m_lastTextBlockToBeEdited == (CodeBlock*) m_selectedTextBlock) {
             updateTextBlockFromText (m_lastTextBlockToBeEdited);
-            m_lastTextBlockToBeEdited = 0;
+            m_lastTextBlockToBeEdited = nullptr;
         }
 
         m_parentDoc->removeTextBlock(m_selectedTextBlock);
         rebuildView(m_lastPara);
         // removeTextBlock(m_selectedTextBlock);
-        m_selectedTextBlock = 0;
+        m_selectedTextBlock = nullptr;
     }
 }
 
@@ -879,7 +880,7 @@ void CodeEditor::slotPasteTextBlock()
 {
     if (m_textBlockToPaste) {
         m_parentDoc->insertTextBlock(m_textBlockToPaste, m_selectedTextBlock);
-        m_textBlockToPaste = 0;
+        m_textBlockToPaste = nullptr;
         rebuildView(m_lastPara);
     }
 }
@@ -916,9 +917,9 @@ void CodeEditor::init(CodeViewerDialog * parentDialog, CodeDocument * parentDoc)
 
     m_newLinePressed = false;
     m_backspacePressed = false;
-    m_textBlockToPaste = 0;
-    m_selectedTextBlock = 0;
-    m_lastTextBlockToBeEdited = 0;
+    m_textBlockToPaste = nullptr;
+    m_selectedTextBlock = nullptr;
+    m_lastTextBlockToBeEdited = nullptr;
 
     setFont(state().font);
 
@@ -962,7 +963,7 @@ void CodeEditor::updateTextBlockFromText(TextBlock * block)
         // Assemble content from editiable paras
         if (info) {
             QList<ParaInfo*> list = info->m_paraList;
-            foreach (ParaInfo * item, list) {
+            for(ParaInfo * item : list) {
                 if (item->isEditable) {
                     int lastpara = item->start+pstart+item->size;
                     int endEdit = block->lastEditableLine();
@@ -1062,7 +1063,7 @@ void CodeEditor::slotCursorPositionChanged()
         int minPos = baseIndent.length();
 
         // add indent chars to the current line, if missing
-        if (!m_backspacePressed && !currentParaText.contains(QRegExp(QChar::fromLatin1('^')+baseIndent))) {
+        if (!m_backspacePressed && !currentParaText.contains(QRegularExpression(QChar::fromLatin1('^')+baseIndent))) {
             textCursor().setPosition(para);
             textCursor().insertText(baseIndent);
 //:TODO:            setCursorPosition(para, pos+minPos);  // crashes the application !?
@@ -1106,7 +1107,7 @@ void CodeEditor::slotCursorPositionChanged()
 
                     // furthermore, If it is nothing but indentation + whitespace
                     // we switch this back to Auto-Generated.
-                    if (cmb && contents.contains(QRegExp(QChar::fromLatin1('^')+baseIndent+QString::fromLatin1("\\s$")))) {
+                    if (cmb && contents.contains(QRegularExpression(QChar::fromLatin1('^')+baseIndent+QString::fromLatin1("\\s$")))) {
                         cmb->setContentType(CodeBlock::AutoGenerated);
                         cmb->syncToParent();
                     }
@@ -1129,13 +1130,13 @@ void CodeEditor::slotCursorPositionChanged()
         if (m_lastTextBlockToBeEdited && (m_lastTextBlockToBeEdited != m_textBlockList.at(para) || !editPara))
         {
             updateTextBlockFromText (m_lastTextBlockToBeEdited);
-            m_lastTextBlockToBeEdited = 0;
+            m_lastTextBlockToBeEdited = nullptr;
         }
 
         if (editPara)
             m_lastTextBlockToBeEdited = m_textBlockList.at(para);
         else
-            m_lastTextBlockToBeEdited = 0;
+            m_lastTextBlockToBeEdited = nullptr;
     }
 
     m_lastPara = para;
@@ -1156,7 +1157,7 @@ bool CodeEditor::paraIsNotSingleLine(int para)
         int pstart = m_textBlockList.indexOf(tBlock);
         TextBlockInfo *info = m_tbInfoMap[tBlock];
         QList<ParaInfo*> list = info->m_paraList;
-        foreach (ParaInfo * item, list) {
+        for(ParaInfo  *item : list) {
             if ((pstart+item->start) <= para && (item->start+pstart+item->size) >= para)
                 if (item->size > 0)
                     return true;
@@ -1188,7 +1189,7 @@ TextBlock* CodeEditor::findTextBlockAt(int characterPos)
             }
         }
     }
-    return 0;
+    return nullptr;
 }
 
 /**
@@ -1225,7 +1226,7 @@ bool CodeEditor::isParaEditable(int para)
             int pstart = m_textBlockList.indexOf(tBlock);
             int relativeLine = para - pstart;
             QList<ParaInfo*> list = info->m_paraList;
-            foreach (ParaInfo * item, list) {
+            for(ParaInfo  *item : list) {
                 if (item->start+pstart <= para && item->start+pstart+item->size >= para) {
                     if (item->isEditable && hasEditableRange) {
                         if (relativeLine >= editStart && relativeLine <= (item->size + editEnd))
@@ -1261,7 +1262,7 @@ void CodeEditor::changeTextBlockHighlighting(TextBlock * tBlock, bool selected)
         }
         QList<ParaInfo*> list = info->m_paraList;
         int pstart = m_textBlockList.indexOf(tBlock);
-        foreach (ParaInfo * item, list) {
+        for(ParaInfo  *item : list) {
             for (int p=(item->start+pstart); p<=(item->start+pstart+item->size); ++p) {
                 if (selected) {
                     if (info->isClickable) {
@@ -1349,7 +1350,7 @@ void CodeEditor::contractSelectedParagraph(int paraToRemove)
             TextBlockInfo *info = m_tbInfoMap[tBlock];
             QList<ParaInfo*> list = info->m_paraList;
             bool lowerStartPosition = false;
-            foreach (ParaInfo * item, list) {
+            for(ParaInfo  *item : list) {
                 if (lowerStartPosition) {
                     item->start -= 1;
                 }
@@ -1384,7 +1385,7 @@ void CodeEditor::expandSelectedParagraph(int priorPara)
 
         // now update the paragraph information
         bool upStartPosition = false;
-        foreach (ParaInfo * item, list) {
+        for(ParaInfo  *item : list) {
             // AFTER we get a match, then following para's need to have start position upped too
             if (upStartPosition)
                 item->start += 1;
@@ -1454,7 +1455,7 @@ void CodeEditor::contentsMouseMoveEvent(QMouseEvent * e)
 
         if (m_lastTextBlockToBeEdited) {
             updateTextBlockFromText (m_lastTextBlockToBeEdited);
-            m_lastTextBlockToBeEdited = 0;
+            m_lastTextBlockToBeEdited = nullptr;
         }
     }
 
