@@ -1,12 +1,7 @@
-/***************************************************************************
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   copyright (C) 2002-2014                                               *
- *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
- ***************************************************************************/
+/*
+    SPDX-License-Identifier: GPL-2.0-or-later
+    SPDX-FileCopyrightText: 2002-2020 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
+*/
 
 // own header
 #include "diagramprintpage.h"
@@ -44,14 +39,14 @@ DiagramPrintPage::DiagramPrintPage(QWidget * parent, UMLDoc * doc)
     setWindowTitle(i18n("&Diagrams"));
     QHBoxLayout * mainLayout = new QHBoxLayout(this);
     mainLayout->setSpacing(10);
-    mainLayout->setMargin(margin);
+    mainLayout->setContentsMargins(margin, margin, margin, margin);
 
     m_pFilterGB = new QGroupBox(i18n("Filter"), this);
     mainLayout->addWidget(m_pFilterGB);
 
     QVBoxLayout * filter = new QVBoxLayout(m_pFilterGB);
     filter->setSpacing(10);
-    filter->setMargin(margin);
+    filter->setContentsMargins(margin, margin, margin, margin);
 
     m_pCurrentRB = new QRadioButton(i18n("&Current diagram"), m_pFilterGB);
     filter->addWidget(m_pCurrentRB);
@@ -71,7 +66,7 @@ DiagramPrintPage::DiagramPrintPage(QWidget * parent, UMLDoc * doc)
 
     QVBoxLayout * select = new QVBoxLayout(m_pSelectGB);
     select->setSpacing(10);
-    select->setMargin(margin);
+    select->setContentsMargins(margin, margin, margin, margin);
 
     m_pTypeCB = new KComboBox(m_pSelectGB);
     select->addWidget(m_pTypeCB);
@@ -205,7 +200,7 @@ void DiagramPrintPage::slotClicked()
         m_pTypeCB->setEnabled(false);
         m_pSelectLW->setEnabled(false);
         m_pSelectLW->clear();
-        foreach (UMLView * view, list) {
+        for(UMLView * view : list) {
             m_pSelectLW->addItem(view->umlScene()->name());
             m_nIdList.append(view->umlScene()->ID());
         }
@@ -216,7 +211,7 @@ void DiagramPrintPage::slotClicked()
         m_pTypeCB->setEnabled(false);
         m_pSelectLW->setEnabled(true);
         m_pSelectLW->clear();
-        foreach (UMLView * view, list) {
+        for(UMLView * view : list) {
             m_pSelectLW->addItem(view->umlScene()->name());
             m_nIdList.append(view->umlScene()->ID());
         }
@@ -226,7 +221,7 @@ void DiagramPrintPage::slotClicked()
         m_pTypeCB->setEnabled(true);
         m_pSelectLW->setEnabled(true);
         m_pSelectLW->clear();
-        foreach (UMLView * view, list) {
+        for(UMLView * view : list) {
             if(view->umlScene()->type() == m_ViewType) {
                 m_pSelectLW->addItem(view->umlScene()->name());
                 m_nIdList.append(view->umlScene()->ID());
@@ -252,7 +247,7 @@ void DiagramPrintPage::slotActivated(int index)
     m_pSelectLW->clear();
 
     m_nIdList.clear();
-    foreach (UMLView * view, list) {
+    for(UMLView * view : list) {
         if (view->umlScene()->type() == m_ViewType) {
             m_pSelectLW->addItem(view->umlScene()->name());
             m_nIdList.append(view->umlScene()->ID());
