@@ -65,8 +65,8 @@ public:
 };
 
 #define DEBUG_AddAction(m) d->debugActions.append(DebugMenu(m))
-#define DEBUG_StartMenu(m) d->debugActions.append(DebugMenu(m->title() + QLatin1String(" - start")))
-#define DEBUG_EndMenu(m) d->debugActions.append(DebugMenu(m->title() + QLatin1String(" - end")))
+#define DEBUG_StartMenu(m) d->debugActions.append(DebugMenu(m->title() + QStringLiteral(" - start")))
+#define DEBUG_EndMenu(m) d->debugActions.append(DebugMenu(m->title() + QStringLiteral(" - end")))
 
 /**
  * Constructs the popup menu
@@ -74,7 +74,7 @@ public:
  * @param parent   The parent to ListPopupMenu.
  */
 ListPopupMenu::ListPopupMenu(QWidget *parent)
-  : KMenu(parent),
+  : QMenu(parent),
     d(new ListPopupMenuPrivate)
 {
 }
@@ -84,23 +84,21 @@ ListPopupMenu::ListPopupMenu(QWidget *parent)
  */
 ListPopupMenu::~ListPopupMenu()
 {
-    foreach (QAction* action, m_actions) {
-        delete action;
-    }
+    qDeleteAll(m_actions);
     m_actions.clear();
     delete d;
 }
 
-KMenu *ListPopupMenu::newMenu(const QString &title, QWidget *widget)
+QMenu *ListPopupMenu::newMenu(const QString &title, QWidget *widget)
 {
-    KMenu *menu = new KMenu(title, widget);
+    QMenu *menu = new QMenu(title, widget);
     DEBUG_StartMenu(menu);
     return menu;
 }
 
-void ListPopupMenu::addMenu(KMenu *menu)
+void ListPopupMenu::addMenu(QMenu *menu)
 {
-    KMenu::addMenu(menu);
+    QMenu::addMenu(menu);
     DEBUG_EndMenu(menu);
 }
 
@@ -118,10 +116,10 @@ void ListPopupMenu::insert(MenuType m)
  * Shortcut for the frequently used addAction() calls.
  *
  * @param m      The MenuType for which to insert a menu item.
- * @param menu   The KMenu for which to insert a menu item.
+ * @param menu   The QMenu for which to insert a menu item.
  * @param s      The entry to be inserted from the action collection
  */
-void ListPopupMenu::insertFromActionKey(const MenuType m, KMenu *menu, const QString &s)
+void ListPopupMenu::insertFromActionKey(const MenuType m, QMenu *menu, const QString &s)
 {
     QAction* action = UMLApp::app()->actionCollection()->action(s);
     insert(m, menu, action->icon(), action->text());
@@ -131,16 +129,16 @@ void ListPopupMenu::insertFromActionKey(const MenuType m, KMenu *menu, const QSt
  * Shortcut for the frequently used addAction() calls.
  *
  * @param m      The MenuType for which to insert a menu item.
- * @param menu   The KMenu for which to insert a menu item.
+ * @param menu   The QMenu for which to insert a menu item.
  */
-void ListPopupMenu::insert(const MenuType m, KMenu* menu)
+void ListPopupMenu::insert(const MenuType m, QMenu* menu)
 {
     // Preprocessor macro for List Popup Menu Insert Small Icon
 #define LPMISI(IT, TXT) m_actions[m] = menu->addAction(Icon_Utils::SmallIcon(Icon_Utils::IT), TXT)
     // Preprocessor macro for List Popup Menu Insert Bar Icon
 #define LPMIBI(IT, TXT) m_actions[m] = menu->addAction(Icon_Utils::BarIcon(Icon_Utils::IT), TXT)
     DEBUG_AddAction(m);
-    Q_ASSERT(menu != 0);
+    Q_ASSERT(menu != nullptr);
     switch (m) {
     case mt_Accept_Signal:              LPMISI(it_Accept_Signal,         i18n("Accept Signal")); break;
     case mt_Accept_Time_Event:          LPMISI(it_Accept_TimeEvent,      i18n("Accept Time Event")); break;
@@ -164,14 +162,14 @@ void ListPopupMenu::insert(const MenuType m, KMenu* menu)
     case mt_CombinedState:              LPMISI(it_State,                 i18nc("add new combined state", "Combined state...")); break;
     case mt_Component:                  LPMISI(it_Component,             i18n("Component")); break;
     //case mt_Component:                  LPMISI(it_Component,             i18n("Component...")); break;
-    case mt_Component_Diagram:          insertFromActionKey(m, menu, QLatin1String("new_component_diagram")); break;
+    case mt_Component_Diagram:          insertFromActionKey(m, menu, QStringLiteral("new_component_diagram")); break;
     case mt_Component_Folder:           LPMIBI(it_Folder,                i18n("Folder")); break;
     case mt_Copy:                       LPMISI(it_Copy,                  i18n("Copy")); break;
     case mt_Cut:                        LPMISI(it_Cut,                   i18n("Cut")); break;
     case mt_Datatype:                   LPMISI(it_Datatype,              i18n("Datatype...")); break;
     case mt_DeepHistory:                LPMISI(it_History_Deep,          i18n("Deep History")); break;
     case mt_Delete:                     LPMISI(it_Delete,                i18n("Delete")); break;
-    case mt_Deployment_Diagram:         insertFromActionKey(m, menu, QLatin1String("new_deployment_diagram")); break;
+    case mt_Deployment_Diagram:         insertFromActionKey(m, menu, QStringLiteral("new_deployment_diagram")); break;
     case mt_Deployment_Folder:          LPMIBI(it_Folder,                i18n("Folder")); break;
     case mt_EditCombinedState:          LPMISI(it_State,                 i18n("Edit combined state")); break;
     case mt_End_Activity:               LPMISI(it_EndState,              i18n("End Activity")); break;
@@ -179,7 +177,7 @@ void ListPopupMenu::insert(const MenuType m, KMenu* menu)
     case mt_Entity:                     LPMISI(it_Entity,                i18n("Entity")); break;
     //case mt_Entity:                     LPMISI(it_Entity,                i18n("Entity...")); break;
     case mt_EntityAttribute:            LPMISI(it_Entity_Attribute,      i18n("Entity Attribute...")); break;
-    case mt_EntityRelationship_Diagram: insertFromActionKey(m, menu, QLatin1String("new_entityrelationship_diagram")); break;
+    case mt_EntityRelationship_Diagram: insertFromActionKey(m, menu, QStringLiteral("new_entityrelationship_diagram")); break;
     case mt_EntityRelationship_Folder:  LPMIBI(it_Folder,                i18n("Folder")); break;
     case mt_Enum:                       LPMISI(it_Enum,                  i18n("Enum...")); break;
     case mt_EnumLiteral:                LPMISI(it_Enum_Literal,          i18n("Enum Literal...")); break;
@@ -260,7 +258,7 @@ void ListPopupMenu::insert(const MenuType m, KMenu* menu)
     case mt_StateFork:                  LPMISI(it_Fork_State,            i18n("Fork")); break;
     case mt_StateJoin:                  LPMISI(it_Join,                  i18n("Join")); break;
     case mt_StateTransition:            LPMISI(it_State_Transition,      i18n("State Transition")); break;
-    case mt_State_Diagram:              insertFromActionKey(m, menu, QLatin1String("new_state_diagram")); break;
+    case mt_State_Diagram:              insertFromActionKey(m, menu, QStringLiteral("new_state_diagram")); break;
     case mt_Subsystem:                  LPMISI(it_Subsystem,             i18n("Subsystem")); break;
     //case mt_Subsystem:                  LPMISI(it_Subsystem,             i18n("Subsystem...")); break;
     case mt_Template:                   LPMISI(it_Template_Class,        i18n("Template")); break;
@@ -269,7 +267,7 @@ void ListPopupMenu::insert(const MenuType m, KMenu* menu)
     case mt_UniqueConstraint:           LPMISI(it_Constraint_Unique,     i18n("Unique Constraint...")); break;
     case mt_UseCase:                    LPMISI(it_UseCase,               i18n("Use Case")); break;
     //case mt_UseCase:                    LPMISI(it_UseCase,               i18n("Use Case...")); break;
-    case mt_UseCase_Diagram:            insertFromActionKey(m, menu, QLatin1String("new_use_case_diagram")); break;
+    case mt_UseCase_Diagram:            insertFromActionKey(m, menu, QStringLiteral("new_use_case_diagram")); break;
     case mt_UseCase_Folder:             LPMIBI(it_Folder,                i18n("Folder")); break;
 
     default:
@@ -309,11 +307,11 @@ void ListPopupMenu::insert(const MenuType m, const QString & text, const bool ch
  * Shortcut for the frequently used addAction() calls.
  *
  * @param m      The MenuType for which to insert a menu item.
- * @param menu   The KMenu for which to insert a menu item.
+ * @param menu   The QMenu for which to insert a menu item.
  * @param icon   The icon for this action.
  * @param text   The text for this action.
  */
-void ListPopupMenu::insert(const MenuType m, KMenu* menu, const QIcon & icon, const QString & text)
+void ListPopupMenu::insert(const MenuType m, QMenu* menu, const QIcon & icon, const QString & text)
 {
     DEBUG_AddAction(m);
     m_actions[m] = menu->addAction(icon, text);
@@ -323,11 +321,11 @@ void ListPopupMenu::insert(const MenuType m, KMenu* menu, const QIcon & icon, co
  * Shortcut for the frequently used addAction() calls.
  *
  * @param m      The MenuType for which to insert a menu item.
- * @param menu   The KMenu for which to insert a menu item.
+ * @param menu   The QMenu for which to insert a menu item.
  * @param text   The text for this action.
  * @param checkable   Sets the action to checkable.
  */
-void ListPopupMenu::insert(const MenuType m, KMenu* menu, const QString & text, const bool checkable)
+void ListPopupMenu::insert(const MenuType m, QMenu* menu, const QString & text, const bool checkable)
 {
     DEBUG_AddAction(m);
     m_actions[m] = menu->addAction(text);
@@ -348,7 +346,7 @@ void ListPopupMenu::insert(const MenuType m, KMenu* menu, const QString & text,
  */
 void ListPopupMenu::insertContainerItems(bool folders, bool diagrams, bool packages)
 {
-    KMenu* menu = newMenu(i18nc("new container menu", "New"), this);
+    QMenu* menu = newMenu(i18nc("new container menu", "New"), this);
     menu->setIcon(Icon_Utils::SmallIcon(Icon_Utils::it_New));
     insertContainerItems(menu, folders, diagrams, packages);
     addMenu(menu);
@@ -363,7 +361,7 @@ void ListPopupMenu::insertContainerItems(bool folders, bool diagrams, bool packa
  * @param diagrams   Set this true if diagram types shall be included as choices.
  * @param packages   Set this true if packages shall be included as choices.
  */
-void ListPopupMenu::insertContainerItems(KMenu* menu, bool folders, bool diagrams, bool packages)
+void ListPopupMenu::insertContainerItems(QMenu* menu, bool folders, bool diagrams, bool packages)
 {
     if (folders)
         insert(mt_Logical_Folder, menu, Icon_Utils::BarIcon(Icon_Utils::it_Folder), i18n("Folder"));
@@ -375,11 +373,11 @@ void ListPopupMenu::insertContainerItems(KMenu* menu, bool folders, bool diagram
     if (packages)
         insert(mt_Package, menu);
     if (diagrams) {
-        insertFromActionKey(mt_Class_Diagram, menu, QLatin1String("new_class_diagram"));
-        insertFromActionKey(mt_Sequence_Diagram, menu, QLatin1String("new_sequence_diagram"));
-        insertFromActionKey(mt_Collaboration_Diagram, menu, QLatin1String("new_collaboration_diagram"));
-        insertFromActionKey(mt_State_Diagram, menu, QLatin1String("new_state_diagram"));
-        insertFromActionKey(mt_Activity_Diagram, menu, QLatin1String("new_activity_diagram"));
+        insertFromActionKey(mt_Class_Diagram, menu, QStringLiteral("new_class_diagram"));
+        insertFromActionKey(mt_Sequence_Diagram, menu, QStringLiteral("new_sequence_diagram"));
+        insertFromActionKey(mt_Collaboration_Diagram, menu, QStringLiteral("new_collaboration_diagram"));
+        insertFromActionKey(mt_State_Diagram, menu, QStringLiteral("new_state_diagram"));
+        insertFromActionKey(mt_Activity_Diagram, menu, QStringLiteral("new_activity_diagram"));
     }
 }
 
@@ -490,16 +488,16 @@ ListPopupMenu* ListPopupMenu::menuFromAction(QAction *action)
             return qvariant_cast<ListPopupMenu*>(value);
         }
     }
-    return 0;
+    return nullptr;
 }
 
 /**
  * Create the 'new' menu
  * @return menu instance
  */
-KMenu *ListPopupMenu::makeNewMenu()
+QMenu *ListPopupMenu::makeNewMenu()
 {
-    KMenu *menu = newMenu(i18nc("new sub menu", "New"), this);
+    QMenu *menu = newMenu(i18nc("new sub menu", "New"), this);
     menu->setIcon(Icon_Utils::SmallIcon(Icon_Utils::it_New));
     return menu;
 }
@@ -510,7 +508,7 @@ KMenu *ListPopupMenu::makeNewMenu()
  */
 void ListPopupMenu::insertSubMenuCategoryType(UMLCategory* category)
 {
-    KMenu* menu = newMenu(i18nc("category type sub menu", "Category Type"), this);
+    QMenu* menu = newMenu(i18nc("category type sub menu", "Category Type"), this);
     insert(mt_DisjointSpecialisation, menu, i18n("Disjoint(Specialisation)"), CHECKABLE);
     insert(mt_OverlappingSpecialisation, menu, i18n("Overlapping(Specialisation)"), CHECKABLE);
     insert(mt_Union, menu, i18n("Union"), CHECKABLE);
@@ -525,7 +523,7 @@ void ListPopupMenu::insertSubMenuCategoryType(UMLCategory* category)
  */
 QAction* ListPopupMenu::getAction(MenuType idx)
 {
-    return m_actions.value(idx, 0);
+    return m_actions.value(idx, nullptr);
 }
 
 // /**
@@ -594,9 +592,9 @@ void ListPopupMenu::setActionEnabled(MenuType idx, bool value)
  */
 void ListPopupMenu::setupActionsData()
 {
-    foreach (QAction *action, m_actions) {
+    for(QAction *action : m_actions) {
         QMap<QString, QVariant> map = action->data().toMap();
-        map[toString(dt_MenuPointer)] = qVariantFromValue(this);
+        map[toString(dt_MenuPointer)] = QVariant::fromValue(this);
         action->setData(QVariant(map));
     }
 
@@ -630,7 +628,7 @@ QString ListPopupMenu::toString(DataType data)
 void ListPopupMenu::dumpActions(const QString &title)
 {
     qDebug().nospace() << title;
-    foreach(DebugMenu e, d->debugActions) {
+    for(DebugMenu e : d->debugActions) {
         if (!e.menu.isEmpty())
             qDebug().nospace() << "  " << e.menu;
         else
